#include "./controller/widget/widget_textures_view.h"

#include <imgui.h>

#include "./graphics/texture.h"

namespace Splash
{

/*************/
void GuiTexturesView::render()
{
    auto textureList = getObjectsOfBaseType<Texture>();
    if (textureList.size() != 0 && _selectedTextureName.empty())
        _selectedTextureName = textureList[0]->getName();

    ImVec2 availableSize = ImGui::GetContentRegionAvail();
    ImGui::BeginChild("##textures", ImVec2(availableSize.x * 0.25, availableSize.y), ImGuiChildFlags_Borders);
    ImGui::Text("Filter list");

    auto leftMargin = static_cast<int>(ImGui::GetCursorScreenPos().x - ImGui::GetWindowPos().x);
    for (const auto& object : textureList)
    {
        auto texture = std::dynamic_pointer_cast<Texture>(object);
        auto spec = texture->getSpec();

        int w = ImGui::GetWindowWidth() - 3 * leftMargin;
        int h = w * spec.height / spec.width;

        if (ImGui::ImageButton(texture->getName().c_str(), (ImTextureID)(intptr_t)texture->getTexId(), ImVec2(w, h), ImVec2(0, 0), ImVec2(1, 1)))
            _selectedTextureName = texture->getName();
        if (ImGui::IsItemHovered())
            ImGui::SetTooltip("%s", texture->getAlias().c_str());
    }
    ImGui::EndChild();

    auto texture = std::dynamic_pointer_cast<Texture>(getObjectPtr(_selectedTextureName));
    if (!texture)
        return;

    ImGui::SameLine();
    ImGui::BeginChild("##textureInfo", ImVec2(0, 0), ImGuiChildFlags_Borders);

    ImGui::Text("Texture name: %s", _selectedTextureName.c_str());
    {
        const auto spec = texture->getSpec();
        ImGui::BeginChild("##textureDisplay", ImVec2(0, 0), ImGuiChildFlags_None, ImGuiWindowFlags_HorizontalScrollbar);
        ImGui::Image((ImTextureID)(intptr_t)(texture->getTexId()), ImVec2(spec.width, spec.height));
        ImGui::EndChild();
    }

    ImGui::EndChild();
}

} // namespace Splash
